@@ -1,32 +1,28 @@
 # curio/__init__.py
 
-__version__ = '0.9'
+__version__ = '1.0'
 
 from .errors import *
+from .queue import *
 from .task import *
-from .signal import *
+from .time import *
 from .kernel import *
 from .sync import *
-from .queue import *
 from .workers import *
 from .network import *
 from .file import *
 from .channel import *
-from .bridge import *
-from .promise import *
 from .thread import *
 
 __all__ = [*errors.__all__,
+           *queue.__all__,
            *task.__all__,
-           *signal.__all__,
+           *time.__all__,
            *kernel.__all__,
            *sync.__all__,
-           *queue.__all__,
            *workers.__all__,
            *network.__all__,
            *file.__all__,
            *channel.__all__,
-           *bridge.__all__,
-           *promise.__all__,
            *thread.__all__,
            ]
