@@ -48,7 +48,7 @@ try:
     from ssl import SSLWantReadError, SSLWantWriteError
     WantRead = (BlockingIOError, InterruptedError, SSLWantReadError)
     WantWrite = (BlockingIOError, InterruptedError, SSLWantWriteError)
-except ImportError:    # pragma: no cover
+except ImportError:
     WantRead = (BlockingIOError, InterruptedError)
     WantWrite = (BlockingIOError, InterruptedError)
 
@@ -78,7 +78,7 @@ class _Fd(object):
         return self.fd
 
     def __repr__(self):
-        return '<fd=%r>' % self.fd
+        return f'<fd={self.fd!r}>'
 
 
 # There is a certain amount of repetition in this class.  It can
@@ -86,7 +86,6 @@ class _Fd(object):
 # other, the KISSS (Keep it Stupid Simple Stupid) principle might be a
 # better policy--just in case someone needs to debug it.
 
-
 class Socket(object):
     '''
     Non-blocking wrapper around a socket object.   The original socket is put
@@ -103,7 +102,7 @@ class Socket(object):
         self._socket_recv = sock.recv
 
     def __repr__(self):
-        return '<curio.Socket %r>' % (self._socket)
+        return f'<curio.Socket {self._socket!r}>'
 
     def __getattr__(self, name):
         return getattr(self._socket, name)
@@ -212,7 +211,7 @@ class Socket(object):
             await _write_wait(self._fileno)
         err = self._socket.getsockopt(SOL_SOCKET, SO_ERROR)
         if err != 0:
-            raise OSError(err, 'Connect call failed %s' % (address,))
+            raise OSError(err, f'Connect call failed {address}')
         if getattr(self, 'do_handshake_on_connect', False):
             await self.do_handshake()
 
@@ -222,7 +221,7 @@ class Socket(object):
                 return self._socket.recvfrom(buffersize, flags)
             except WantRead:
                 await _read_wait(self._fileno)
-            except WantWrite:       # pragma: no cover
+            except WantWrite:
                 await _write_wait(self._fileno)
 
     async def recvfrom_into(self, buffer, bytes=0, flags=0):
@@ -325,7 +324,7 @@ class StreamBase(object):
         self._buffer = bytearray()
 
     def __repr__(self):
-        return '<curio.%s %r>' % (type(self).__name__, self._file)
+        return f'<curio.{type(self).__name__} {self._file!r}>'
 
     def fileno(self):
         return int(self._fileno)
@@ -390,7 +389,7 @@ class StreamBase(object):
             remaining = len(view)
             total_read = 0
 
-            # It's possible that there is data already buffered on this stream. 
+            # It's possible that there is data already buffered on this stream.
             # If so, we have to copy into the memory buffer first.
             buffered = len(self._buffer)
             tocopy = remaining if (remaining < buffered) else buffered
@@ -419,8 +418,8 @@ class StreamBase(object):
                 except WantWrite:
                     await _write_wait(self._fileno)
             return total_read
-        
-    async def readline(self):
+
+    async def readline(self, maxlen=None):
         while True:
             nl_index = self._buffer.find(b'\n')
             if nl_index >= 0:
@@ -633,3 +632,4 @@ class SocketStream(StreamBase):
         except errors.CancelledError as e:
             e.bytes_written = nwritten
             raise
+
